This allows using dev#partlabel syntax.

Signed-off-by: Sean Anderson <sean.ander...@seco.com>
---

Changes in v2:
- Add stub for when CONFIG_PARTITIONS=n

 fs/fs.c        |  4 ++--
 include/part.h | 12 +++++++++++-
 2 files changed, 13 insertions(+), 3 deletions(-)

diff --git a/fs/fs.c b/fs/fs.c
index 900928c394..b7936fd4cf 100644
--- a/fs/fs.c
+++ b/fs/fs.c
@@ -385,8 +385,8 @@ int fs_set_blk_dev(const char *ifname, const char 
*dev_part_str, int fstype)
        }
 #endif
 
-       part = blk_get_device_part_str(ifname, dev_part_str, &fs_dev_desc,
-                                       &fs_partition, 1);
+       part = part_get_info_by_dev_and_name_or_num(ifname, dev_part_str, 
&fs_dev_desc,
+                                                   &fs_partition, 1);
        if (part < 0)
                return -1;
 
diff --git a/include/part.h b/include/part.h
index 7f78271a98..419c859708 100644
--- a/include/part.h
+++ b/include/part.h
@@ -230,7 +230,7 @@ int part_get_info_by_name(struct blk_desc *dev_desc,
  * @param[in] allow_whole_dev true to allow the user to select partition 0
  *             (which means the whole device), false to require a valid
  *             partition number >= 1
  * @return 0 on success, or a negative on error
  */
 int part_get_info_by_dev_and_name_or_num(const char *dev_iface,
                                         const char *dev_part_str,
@@ -275,6 +275,16 @@ static inline int blk_get_device_part_str(const char 
*ifname,
                                          struct disk_partition *info,
                                          int allow_whole_dev)
 { *dev_desc = NULL; return -1; }
+static inline int
+part_get_info_by_dev_and_name_or_num(const char *dev_iface,
+                                    const char *dev_part_str,
+                                    struct blk_desc **dev_desc,
+                                    struct disk_partition *part_info,
+                                    int allow_whole_dev)
+{
+       *dev_desc = NULL;
+       return -ENOSYS;
+}
 #endif
 
 /*
@@ -230,7 +230,7 @@ int part_get_info_by_name(struct blk_desc *dev_desc,
  *             (which means the whole device), false to require a valid
  *             partition number >= 1
- * @return 0 on success, or a negative on error
+ * @return the partition number on success, or negative errno on error
  */
 int part_get_info_by_dev_and_name_or_num(const char *dev_iface,
-- 
2.25.1

Reply via email to